@@ -18,6 +18,8 @@ pub mod issues;
 pub mod jobs;
 pub mod labels;
 pub mod members;
+pub mod merge_requests;
+pub mod milestones;
 pub mod pipelines;
 mod project;
 mod projects;
