@@ -5,13 +5,10 @@
 // except according to those terms.
 
 macro_rules! impl_id {
-    ( $name:ident ) => {
-        /* This bit of the macro handles the repetitive nature of creating new identifiers.
-         * Unfortunately, it doesn't work with serde_codegen, so until either plugins are stable or
-         * nightly is required, just implement things by hand.
-        #[derive(Serialize, Deserialize, Debug, Clone, Copy, PartialEq, Eq)]
+    ( $name:ident, $doc:expr$(,)? ) => {
+        #[derive(Serialize, Deserialize, Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord)]
+        #[doc = $doc]
         pub struct $name(u64);
-         */
 
         impl $name {
             /// Create a new id.
@@ -35,6 +32,7 @@ macro_rules! impl_id {
 
 macro_rules! enum_serialize {
     ( $name:ident -> $desc:expr, $( $value:ident => $str:expr $( ; $opt:expr )*, )+ ) => {
+        #[allow(deprecated)]
         impl $name {
             /// String representation of the variant.
             pub fn as_str(&self) -> &'static str {
@@ -44,6 +42,7 @@ macro_rules! enum_serialize {
             }
         }
 
+        #[allow(deprecated)]
         impl Serialize for $name {
             fn serialize<S>(&self, serializer: S) -> ::std::result::Result<S::Ok, S::Error>
                 where S: Serializer,
@@ -52,6 +51,7 @@ macro_rules! enum_serialize {
             }
         }
 
+        #[allow(deprecated)]
         impl<'de> Deserialize<'de> for $name {
             fn deserialize<D>(deserializer: D) -> ::std::result::Result<Self, D::Error>
                 where D: Deserializer<'de>,
